@@ -140,8 +140,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
         if vertexAttrProcess=="escape":
             nodeType=rawSchemaJson["vertex"][vertexI]["node_type"]
             nodeIdAttr=rawSchemaJson["vertex"][vertexI]["id_col"]
-            csvDfItem=pd.DataFrame([row for row in json.loads(csvDfItem.to_json(orient="records")) 
-                                        if existTag(nodeType, nodeIdAttr, row[rawSchemaJson["vertex"][vertexI]["id_col"]],gClient)==False])
+            csvDfItem=csvDfItem.loc[csvDfItem[nodeIdAttr].map(lambda nodeAttrVal:existTag(nodeType, nodeIdAttr, nodeAttrVal,gClient)==False)]
         elif vertexAttrProcess=="plus":
             
             nodeItemCInfoDf=csvDfItem.copy(deep=True)
@@ -309,7 +308,9 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
     return rawSchemaJson
 
 def buildGraphDB(gClient,uploadSchemaJson,realDbName=None,force=False):
-    
+    '''
+    按照uploadSchemaJson初始化图数据库
+    '''
     typeDefaultDict={
         "string":"null",
         "double":0.0,
