@@ -154,6 +154,8 @@ def createSchemaFromSchemaJson(schemaJson,graphClient):
     createTagIndexErrCode=0
     rebuildTagIndexErrCode=0
     createEdgeErrCode=0
+    schemaJson["vertex"]=schemaJson.get("vertex",[])+[{"node_type":"Alias","old_id_col":"Name","attr_type_map":{"Name":"string"}}]
+    schemaJson["edge"]=schemaJson.get("edge",[])+[{"edge_type":"aliasNameOf","attr_type_map":{}}]
     if "vertex" in schemaJson: # 构建节点schema
         schemaTagList=schemaJson["vertex"]
         for schemaTagItem in schemaTagList:
